==> org.knime.base.source_2.5.2.0032292.jar: org/knime/base/node/viz/plotter/Plotter2DScrollPane.java <==
/* 
 * ------------------------------------------------------------------------
 *
 *  Copyright (C) 2003 - 2011
 *  University of Konstanz, Germany and
 *  KNIME GmbH, Konstanz, Germany
 *  Website: http://www.knime.org; Email: contact@knime.org
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, Version 3, as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, see <http://www.gnu.org/licenses>.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  KNIME interoperates with ECLIPSE solely via ECLIPSE's plug-in APIs.
 *  Hence, KNIME and ECLIPSE are both independent programs and are not
 *  derived from each other. Should, however, the interpretation of the
 *  GNU GPL Version 3 ("License") under any applicable laws result in
 *  KNIME and ECLIPSE being a combined program, KNIME GMBH herewith grants
 *  you the additional permission to use and propagate KNIME together with
 *  ECLIPSE with only the license terms in place for ECLIPSE applying to
 *  ECLIPSE and the GNU GPL Version 3 applying for KNIME, provided the
 *  license terms of ECLIPSE themselves allow for the respective use and
 *  propagation of ECLIPSE together with KNIME.
 *
 *  Additional permission relating to nodes for KNIME that extend the Node
 *  Extension (and in particular that are based on subclasses of NodeModel,
 *  NodeDialog, and NodeView) and that only interoperate with KNIME through
 *  standard APIs ("Nodes"):
 *  Nodes are deemed to be separate and independent programs and to not be
 *  covered works.  Notwithstanding anything to the contrary in the
 *  License, the License does not apply to Nodes, you are not required to
 *  license Nodes under the License, and you are granted a license to
 *  prepare and propagate Nodes, in each case even if such Nodes are
 *  propagated with or for interoperation with KNIME.  The owner of a Node
 *  may freely choose the license terms applicable to such Node, including
 *  when such Node is propagated with or for interoperation with KNIME.
 * -------------------------------------------------------------------
 * 
 * History
 *   01.02.2006 (sieb): created
 */
package org.knime.base.node.viz.plotter;

import java.awt.Component;
import java.awt.LayoutManager;

import javax.swing.JScrollPane;
import javax.swing.ScrollPaneLayout;

/**
 * Overrides the default <code>JScrollPane</code> to force the application of
 * the own <code>Plotter2DScrollPaneLayout</code> overriding the default
 * <code>ScrollPaneLayout</code>.
 * 
 * @see org.knime.base.node.viz.plotter.Plotter2DScrollPaneLayout
 * @author Christoph Sieb, University of Konstanz
 */
public class Plotter2DScrollPane extends JScrollPane {

    /**
     * The constructor for a scatter plotter scroll pane.
     * 
     * @param view the underlying view of the scroll pane. In case of the
     *            scatterplotter this is the drawing pane rendering the dots
     */
    public Plotter2DScrollPane(final Component view) {
        super(view);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void setLayout(final LayoutManager layout) {

        LayoutManager managerToSet = null;
        if (!(layout instanceof Plotter2DScrollPaneLayout)) {
            managerToSet = new Plotter2DScrollPaneLayout();
        } else {
            managerToSet = layout;
        }

        if (managerToSet instanceof ScrollPaneLayout) {
            super.setLayout(managerToSet);
            ((ScrollPaneLayout)managerToSet).syncWithScrollPane(this);
        } else if (managerToSet == null) {
            super.setLayout(managerToSet);
        } else {
            String s = "layout of JScrollPane must be a ScrollPaneLayout";
            throw new ClassCastException(s);
        }
    }

}

==> org.knime.base.source_2.7.2.0036614.jar: org/knime/base/node/viz/plotter/Plotter2DScrollPane.java <==
/*
 * ------------------------------------------------------------------------
 *
 *  Copyright (C) 2003 - 2011
 *  University of Konstanz, Germany and
 *  KNIME GmbH, Konstanz, Germany
 *  Website: http://www.knime.org; Email: contact@knime.org
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License, Version 3, as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, see <http://www.gnu.org/licenses>.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  KNIME interoperates with ECLIPSE solely via ECLIPSE's plug-in APIs.
 *  Hence, KNIME and ECLIPSE are both independent programs and are not
 *  derived from each other. Should, however, the interpretation of the
 *  GNU GPL Version 3 ("License") under any applicable laws result in
 *  KNIME and ECLIPSE being a combined program, KNIME GMBH herewith grants
 *  you the additional permission to use and propagate KNIME together with
 *  ECLIPSE with only the license terms in place for ECLIPSE applying to
 *  ECLIPSE and the GNU GPL Version 3 applying for KNIME, provided the
 *  license terms of ECLIPSE themselves allow for the respective use and
 *  propagation of ECLIPSE together with KNIME.
 *
 *  Additional permission relating to nodes for KNIME that extend the Node
 *  Extension (and in particular that are based on subclasses of NodeModel,
 *  NodeDialog, and NodeView) and that only interoperate with KNIME through
 *  standard APIs ("Nodes"):
 *  Nodes are deemed to be separate and independent programs and to not be
 *  covered works.  Notwithstanding anything to the contrary in the
 *  License, the License does not apply to Nodes, you are not required to
 *  license Nodes under the License, and you are granted a license to
 *  prepare and propagate Nodes, in each case even if such Nodes are
 *  propagated with or for interoperation with KNIME.  The owner of a Node
 *  may freely choose the license terms applicable to such Node, including
 *  when such Node is propagated with or for interoperation with KNIME.
 * -------------------------------------------------------------------
 *
 * History
 *   01.02.2006 (sieb): created
 */
package org.knime.base.node.viz.plotter;

import java.awt.Component;
import java.awt.LayoutManager;

import javax.swing.JScrollPane;
import javax.swing.ScrollPaneLayout;

/**
 * Overrides the default <code>JScrollPane</code> to force the application of
 * the own <code>Plotter2DScrollPaneLayout</code> overriding the default
 * <code>ScrollPaneLayout</code>.
 *
 * @see org.knime.base.node.viz.plotter.Plotter2DScrollPaneLayout
 * @author Christoph Sieb, University of Konstanz
 */
public class Plotter2DScrollPane extends JScrollPane {

    /**
     * The constructor for a scatter plotter scroll pane.
     *
     * @param view the underlying view of the scroll pane. In case of the
     *            scatterplotter this is the drawing pane rendering the dots
     */
    public Plotter2DScrollPane(final Component view) {
        super(view);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void setLayout(final LayoutManager layout) {
        LayoutManager managerToSet;
        if (!(layout instanceof Plotter2DScrollPaneLayout)) {
            managerToSet = new Plotter2DScrollPaneLayout();
        } else {
            managerToSet = layout;
        }

        super.setLayout(managerToSet);
        ((ScrollPaneLayout)managerToSet).syncWithScrollPane(this);
    }

}
